==> tomcat-plugin-3.7.0-sources.jar: com/xebialabs/deployit/plugin/tomcat/processor/CommonContextNameInjector.java <==
package com.xebialabs.deployit.plugin.tomcat.processor;

import com.google.common.collect.Iterables;
import com.xebialabs.deployit.plugin.api.deployment.execution.DeploymentStep;
import com.xebialabs.deployit.plugin.api.deployment.planning.PrePlanProcessor;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.DeltaSpecification;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.generic.deployed.AbstractDeployed;
import com.xebialabs.deployit.plugin.tomcat.deployed.ContextElement;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Collections;
import java.util.List;

public class CommonContextNameInjector {

    public static final Type COMMON_CONTEXT_TYPE = Type.valueOf("tomcat.CommonContext");


    @PrePlanProcessor
    public List<DeploymentStep> injectContextNameInToContextElements(DeltaSpecification spec) {
        Iterable<AbstractDeployed<?>> deployeds = findDeployedsTargetedToCommonContexts(spec.getDeltas());
        logger.debug("Found {} deployeds targeted to common context", Iterables.size(deployeds));
        injectCommonContextNameIntoContextElements(deployeds);
        return Collections.emptyList();
    }

    protected void injectCommonContextNameIntoContextElements(Iterable<AbstractDeployed<?>> abstractDeployeds) {
        Iterable<ContextElement<?>> elements = extractContextElements(abstractDeployeds);
        logger.debug("Found {} context elements targeted to common context", Iterables.size(elements));
        for (ContextElement<?> resource : elements) {
            resource.setContext("context");
        }
    }

    protected Iterable<ContextElement<?>> extractContextElements(Iterable<AbstractDeployed<?>> abstractDeployeds) {
        return Utils.extractDeployedContextElements(abstractDeployeds);
    }

    protected Iterable<AbstractDeployed<?>> findDeployedsTargetedToCommonContexts(List<Delta> deltas) {
        return Utils.findDeployedsTargetedToContainer(deltas, COMMON_CONTEXT_TYPE);
    }

    private static final Logger logger = LoggerFactory.getLogger(CommonContextNameInjector.class);

}

==> tomcat-plugin-3.9.2-sources.jar: com/xebialabs/deployit/plugin/tomcat/processor/CommonContextNameInjector.java <==
package com.xebialabs.deployit.plugin.tomcat.processor;

import java.util.Collections;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.collect.Iterables;

import com.xebialabs.deployit.plugin.api.deployment.planning.PrePlanProcessor;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.DeltaSpecification;
import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.deployit.plugin.generic.deployed.AbstractDeployed;
import com.xebialabs.deployit.plugin.tomcat.deployed.ContextElement;

public class CommonContextNameInjector {

    public static final Type COMMON_CONTEXT_TYPE = Type.valueOf("tomcat.CommonContext");


    @PrePlanProcessor
    public List<Step> injectContextNameInToContextElements(DeltaSpecification spec) {
        Iterable<AbstractDeployed<?>> deployeds = findDeployedsTargetedToCommonContexts(spec.getDeltas());
        logger.debug("Found {} deployeds targeted to common context", Iterables.size(deployeds));
        injectCommonContextNameIntoContextElements(deployeds);
        return Collections.emptyList();
    }

    protected void injectCommonContextNameIntoContextElements(Iterable<AbstractDeployed<?>> abstractDeployeds) {
        Iterable<ContextElement<?>> elements = extractContextElements(abstractDeployeds);
        logger.debug("Found {} context elements targeted to common context", Iterables.size(elements));
        for (ContextElement<?> resource : elements) {
            resource.setContext("context");
        }
    }

    protected Iterable<ContextElement<?>> extractContextElements(Iterable<AbstractDeployed<?>> abstractDeployeds) {
        return Utils.extractDeployedContextElements(abstractDeployeds);
    }

    protected Iterable<AbstractDeployed<?>> findDeployedsTargetedToCommonContexts(List<Delta> deltas) {
        return Utils.findDeployedsTargetedToContainer(deltas, COMMON_CONTEXT_TYPE);
    }

    private static final Logger logger = LoggerFactory.getLogger(CommonContextNameInjector.class);

}
